soph.py
=======

-----

.. contents:: **Table of Contents**
    :backlinks: none

Installation
------------

soph.py is distributed on `PyPI <https://pypi.org>`_ as a universal
wheel and is available on Linux/macOS and Windows and supports
Python 2.7/3.5+ and PyPy.

.. code-block:: bash

    $ pip install soph

License
-------

soph.py is distributed under the terms of the
`MIT License <https://choosealicense.com/licenses/mit>`_.
